==> geeklog-1.8.1-jp-1.1.tar.gz: geeklog-1.8.1-jp-1.1/plugins/spamx/language/french_canada.php <==
<?php

/**
 * File: french_canada.php
 * This is the French language page for the Geeklog Spam-X Plug-in!
 * 
 * Copyright (C) 2004-2005 by the following authors:
 * Author        Tom Willett        tomw AT pigstye DOT net
 *
 * French translation provided by Alain Ponton.
 *
 * Licensed under GNU General Public License
 *
 * $Id: french_canada.php,v 1.11 2008/05/02 15:08:10 dhaun Exp $
 */

global $LANG32;

$LANG_SX00 = array(
    'inst1' => '<p>Si vous faites ce qui suit, alors tout le monde ',
    'inst2' => 'pourra voir et importer votre Liste Noire personnelle. Nous pouvons alors crer une base de donnes ',
    'inst3' => 'plus efficace.</p><p>Si vous avez soumis votre site et ne dsirez pas qu\'il reste sur cette liste ',
    'inst4' => 'envoyez un courriel   <a href="mailto:spamx@pigstye.net">spamx@pigstye.net</a> pour me le faire savoir. ',
    'inst5' => 'Toutes les demandes seront honores',
    'submit' => 'Soumettre',
    'subthis' => ' la base de donnes centrale Spam-X',
    'secbut' => 'Ce second bouton permet de crer un fichier RDF afin de permettre l\'importation de votre liste.',
    'sitename' => 'Nom du Site: ',
    'URL' => 'URL vers la Liste Spam-X: ',
    'RDF' => 'URL du fichier RDF: ',
    'impinst1a' => 'Avant d\'utiliser l\'utilitaire anti-comentaires indsirables Spam-X pour voir et importer les listes noires personnelles des autres',
    'impinst1b' => ' sites, je vous demande d\'utiliser les deux boutons suivants. (Le dernier est obligatoire.)',
    'impinst2' => 'Le premier soumet votre site web au site Gplugs/Spam-X afin de l\'ajouter  la liste principale des ',
    'impinst2a' => 'sites partagant leur liste noire. (Note: si vous avez plusieurs sites, vous devriez en dsigner un comme site matre ',
    'impinst2b' => 'et soumettre ce dernier seulement. Ceci vous permettra de mettre votre site  jour facilement tout en conservant une liste plus petite.) ',
    'impinst2c' => 'Aprs avoir cliqu le bouton Soumettre, utilisez le bouton [prcdent] de votre navigateur pour revenir  cette page.',
    'impinst3' => 'Les donnes suivantes seront envoyes: (vous pouvez les modifier si ncessaire).',
    'availb' => 'Listes Noires Disponibles',
    'clickv' => 'Cliquez pour voir la Liste Noire',
    'clicki' => 'Cliquez pour Importer la Liste Noire',
    'ok' => 'OK',
    'rsscreated' => 'Fil RSS Cr',
    'add1' => 'Ajout ',
    'add2' => ' entres de la',
    'add3' => '\' liste noire de.',
    'adminc' => 'Commandes Administration:',
    'mblack' => 'Ma Liste Noire:',
    'rlinks' => 'Liens relatifs:',
    'e3' => 'Pour ajouter les mots de la liste de Censure Geeklogs Cliquez le bouton:',
    'addcen' => 'Ajouter Liste de Censure',
    'addentry' => 'Ajouter l\'entre',
    'e1' => 'Pour supprimer une entre cliquez dessus.',
    'e2' => 'Pour ajouter une entre, entrez-la dans la case et cliquez Ajouter.  Les entres peuvent utiliser les expressions rgulires compltes de Perl.',
    'pblack' => 'Liste Noire Personnelle Spam-X',
    'conmod' => 'Configurer utilisation du module Spam-X',
    'acmod' => 'Modules Action de Spam-X',
    'exmod' => 'Modules Vrification de Spam-X',
    'actmod' => 'Modules actifs',
    'avmod' => 'Modules disponibles',
    'coninst' => '<hr' . XHTML . '>Cliquez sur un module actif pour le supprimer, cliquez sur un module disponible pour l\'ajouter.<br' . XHTML . '>Les modules sont excuts dans l\'ordre affich.',
    'fsc' => 'Correspondance de commentaire indsirable trouve ',
    'fsc1' => ' envoy par l\'utilisateur ',
    'fsc2' => ' adresse IP ',
    'uMTlist' => 'Mettre  jour Liste Noire principale',
    'uMTlist2' => ': Ajout ',
    'uMTlist3' => ' entres et supprimes ',
    'entries' => ' entres.',
    'uPlist' => 'Mettre  jour Liste Noire personnelle',
    'entriesadded' => 'entres ajoutes',
    'entriesdeleted' => 'entres supprimes',
    'viewlog' => 'Voir fichier log Spam-X',
    'clearlog' => 'Vider fichier ',
    'logcleared' => '- fichier log Spam-X vide',
    'plugin' => 'Plugin',
    'access_denied' => 'Accs refus',
    'access_denied_msg' => 'Seulement les utilisateurs Root ont accs  cette page.  Votre code d\'usager et votre adresse IP ont t enregistrs.',
    'admin' => 'Administration Plugin',
    'install_header' => 'Installer/Dsinstaller Plugin',
    'installed' => 'Le Plugin est install',
    'uninstalled' => 'le Plugin n\'est pas install',
    'install_success' => 'Installation russie',
    'install_failed' => 'Echec de l\'installation  -- Voyez votre le fichier d\'erreur pour en connatre la raison.',
    'uninstall_msg' => 'Dsinstallation du Plugin russie',
    'install' => 'Installer',
    'uninstall' => 'Dsinstaller',
    'warning' => 'Attention! Plugin encore activ',
    'enabled' => 'Dsactivez le plugin avant la dsinstallation.',
    'readme' => 'ARRTEZ! Avant d\'installer veuillez lire le ',
    'installdoc' => 'Document d\'installation.',
    'spamdeleted' => 'Commentaire indsirable supprim',
    'foundspam' => 'Correspondance de commentaire indsirable trouve ',
    'foundspam2' => ' envoy par l\'utilisateur ',
    'foundspam3' => ' adresse IP ',
    'deletespam' => 'Supprimer Commentaire',
    'numtocheck' => 'Nombre de commentaires  vrifier',
    'note1' => '<p>Note: La suppression en lot a pour but de faciliter la tche lorsque vous tes victime d\'un',
    'note2' => ' commentaire indsirable et que Spam-X ne le reconnat pas.  <ul><li>Trouvez d\'abord le(s) lien(s) ou autre ',
    'note3' => 'identificateurs de ce commentaire indsirable et ajoutez-le  votre liste noire personnelle.</li><li>Ensuite ',
    'note4' => 'revenez ici et excutez Spam-X pour vrifier les derniers commentaires.</li></ul><p>Les commentaires ',
    'note5' => 'sont vrifis  partir des plus rcents -- vrifier plus de commentaires ',
    'note6' => 'ncessite plus de temps pour la vrification</p>',
    'masshead' => '<hr' . XHTML . '><h1 align="center">Suppression de commentaires en lot</h1>',
    'masstb' => '<hr' . XHTML . '><h1 align="center">Mass Delete Trackback Spam</h1>',
    'comdel' => ' commentaires supprims.',
    'initial_Pimport' => '<p>Importer Liste Noire Personnelle"',
    'initial_import' => 'Importer Liste Noire Principale Originale',
    'import_success' => '<p>Importation avec succs de %d entres dans la liste noire.',
    'import_failure' => '<p><strong>Erreur:</strong> Aucune entre trouve.',
    'allow_url_fopen' => '<p>Dsol, la configuration de votre serveur web ne permet pas la lecture de fichiers distants (<code>allow_url_fopen</code> est dsactiv). Veuillez tlcharger la liste noire de l\'adresse suivante et placez-la dans le rpertoire "data" de Geeklog, <tt>%s</tt>, avant un nouvel essai:',
    'documentation' => 'Documentation du Plugin Spam-X',
    'emailmsg' => "Un nouveau commentaire indsirable a t envoy  \"%s\"\nUser UID:\"%s\"\n\nContent:\"%s\"",
    'emailsubject' => 'Spam post at %s',
    'ipblack' => 'Spam-X IP Blacklist',
    'ipofurlblack' => 'Spam-X IP of URL Blacklist',
    'headerblack' => 'Spam-X HTTP Header Blacklist',
    'headers' => 'Request headers:',
    'stats_headline' => 'Spam-X Statistics',
    'stats_page_title' => 'Blacklist',
    'stats_entries' => 'Entries',
    'stats_mtblacklist' => 'MT-Blacklist',
    'stats_pblacklist' => 'Personal Blacklist',
    'stats_ip' => 'Blocked IPs',
    'stats_ipofurl' => 'Blocked by IP of URL',
    'stats_header' => 'HTTP headers',
    'stats_deleted' => 'Posts deleted as spam',
    'plugin_name' => 'Spam-X',
    'slvwhitelist' => 'SLV Whitelist'
);

// Define Messages that are shown when Spam-X module action is taken
$PLG_spamx_MESSAGE128 = 'Commentaire indsirable dtect et Commentaire ou Message supprim.';
$PLG_spamx_MESSAGE8 = 'Commentaire indsirable dtect et Commentaire supprim. Courriel envoy  l\Administrateur.';

// Messages for the plugin upgrade
$PLG_spamx_MESSAGE3001 = 'Plugin upgrade not supported.';
$PLG_spamx_MESSAGE3002 = $LANG32[9];

// Localization of the Admin Configuration UI
$LANG_configsections['spamx'] = array(
    'label' => 'Spam-X',
    'title' => 'Spam-X Configuration'
);

$LANG_confignames['spamx'] = array(
    'spamx_action' => 'Spam-X Actions',
    'notification_email' => 'Notification Email',
    'logging' => 'Enable Logging',
    'timeout' => 'Timeout'
);

$LANG_configsubgroups['spamx'] = array(
    'sg_main' => 'Main Settings'
);

$LANG_tab['spamx'] = array(
    'tab_main' => 'Spam-X Main Settings'
);

$LANG_fs['spamx'] = array(
    'fs_main' => 'Spam-X Main Settings'
);

// Note: entries 0, 1, 9, and 12 are the same as in $LANG_configselects['Core']
$LANG_configselects['spamx'] = array(
    0 => array('True' => 1, 'False' => 0),
    1 => array('True' => true, 'False' => false)
);

?>

==> geeklog-2.0.0-jp-1.0.tar.gz: geeklog-2.0.0-jp-1.0/plugins/spamx/language/french_canada.php <==
<?php

/**
 * File: french_canada.php
 * This is the French language page for the Geeklog Spam-X Plug-in!
 * 
 * Copyright (C) 2004-2005 by the following authors:
 * Author        Tom Willett        tomw AT pigstye DOT net
 *
 * French translation provided by Alain Ponton.
 *
 * Licensed under GNU General Public License
 *
 * $Id: french_canada.php,v 1.11 2008/05/02 15:08:10 dhaun Exp $
 */

global $LANG32;

$LANG_SX00 = array(
    'inst1' => '<p>Si vous faites ce qui suit, alors tout le monde ',
    'inst2' => 'pourra voir et importer votre Liste Noire personnelle. Nous pouvons alors crer une base de donnes ',
    'inst3' => 'plus efficace.</p><p>Si vous avez soumis votre site et ne dsirez pas qu\'il reste sur cette liste ',
    'inst4' => 'envoyez un courriel   <a href="mailto:spamx@pigstye.net">spamx@pigstye.net</a> pour me le faire savoir. ',
    'inst5' => 'Toutes les demandes seront honores',
    'submit' => 'Soumettre',
    'subthis' => ' la base de donnes centrale Spam-X',
    'secbut' => 'Ce second bouton permet de crer un fichier RDF afin de permettre l\'importation de votre liste.',
    'sitename' => 'Nom du Site: ',
    'URL' => 'URL vers la Liste Spam-X: ',
    'RDF' => 'URL du fichier RDF: ',
    'impinst1a' => 'Avant d\'utiliser l\'utilitaire anti-comentaires indsirables Spam-X pour voir et importer les listes noires personnelles des autres',
    'impinst1b' => ' sites, je vous demande d\'utiliser les deux boutons suivants. (Le dernier est obligatoire.)',
    'impinst2' => 'Le premier soumet votre site web au site Gplugs/Spam-X afin de l\'ajouter  la liste principale des ',
    'impinst2a' => 'sites partagant leur liste noire. (Note: si vous avez plusieurs sites, vous devriez en dsigner un comme site matre ',
    'impinst2b' => 'et soumettre ce dernier seulement. Ceci vous permettra de mettre votre site  jour facilement tout en conservant une liste plus petite.) ',
    'impinst2c' => 'Aprs avoir cliqu le bouton Soumettre, utilisez le bouton [prcdent] de votre navigateur pour revenir  cette page.',
    'impinst3' => 'Les donnes suivantes seront envoyes: (vous pouvez les modifier si ncessaire).',
    'availb' => 'Listes Noires Disponibles',
    'clickv' => 'Cliquez pour voir la Liste Noire',
    'clicki' => 'Cliquez pour Importer la Liste Noire',
    'ok' => 'OK',
    'rsscreated' => 'Fil RSS Cr',
    'add1' => 'Ajout ',
    'add2' => ' entres de la',
    'add3' => '\' liste noire de.',
    'adminc' => 'Commandes Administration:',
    'mblack' => 'Ma Liste Noire:',
    'rlinks' => 'Liens relatifs:',
    'e3' => 'Pour ajouter les mots de la liste de Censure Geeklogs Cliquez le bouton:',
    'addcen' => 'Ajouter Liste de Censure',
    'addentry' => 'Ajouter l\'entre',
    'e1' => 'Pour supprimer une entre cliquez dessus.',
    'e2' => 'Pour ajouter une entre, entrez-la dans la case et cliquez Ajouter.  Les entres peuvent utiliser les expressions rgulires compltes de Perl.',
    'pblack' => 'Liste Noire Personnelle Spam-X',
    'sfseblack' => 'Spam-X SFS Email Blacklist',
    'conmod' => 'Configurer utilisation du module Spam-X',
    'acmod' => 'Modules Action de Spam-X',
    'exmod' => 'Modules Vrification de Spam-X',
    'actmod' => 'Modules actifs',
    'avmod' => 'Modules disponibles',
    'coninst' => '<hr' . XHTML . '>Cliquez sur un module actif pour le supprimer, cliquez sur un module disponible pour l\'ajouter.<br' . XHTML . '>Les modules sont excuts dans l\'ordre affich.',
    'fsc' => 'Correspondance de commentaire indsirable trouve ',
    'fsc1' => ' envoy par l\'utilisateur ',
    'fsc2' => ' adresse IP ',
    'uMTlist' => 'Mettre  jour Liste Noire principale',
    'uMTlist2' => ': Ajout ',
    'uMTlist3' => ' entres et supprimes ',
    'entries' => ' entres.',
    'uPlist' => 'Mettre  jour Liste Noire personnelle',
    'entriesadded' => 'entres ajoutes',
    'entriesdeleted' => 'entres supprimes',
    'viewlog' => 'Voir fichier log Spam-X',
    'clearlog' => 'Vider fichier ',
    'logcleared' => '- fichier log Spam-X vide',
    'plugin' => 'Plugin',
    'access_denied' => 'Accs refus',
    'access_denied_msg' => 'Seulement les utilisateurs Root ont accs  cette page.  Votre code d\'usager et votre adresse IP ont t enregistrs.',
    'admin' => 'Administration Plugin',
    'install_header' => 'Installer/Dsinstaller Plugin',
    'installed' => 'Le Plugin est install',
    'uninstalled' => 'le Plugin n\'est pas install',
    'install_success' => 'Installation russie',
    'install_failed' => 'Echec de l\'installation  -- Voyez votre le fichier d\'erreur pour en connatre la raison.',
    'uninstall_msg' => 'Dsinstallation du Plugin russie',
    'install' => 'Installer',
    'uninstall' => 'Dsinstaller',
    'warning' => 'Attention! Plugin encore activ',
    'enabled' => 'Dsactivez le plugin avant la dsinstallation.',
    'readme' => 'ARRTEZ! Avant d\'installer veuillez lire le ',
    'installdoc' => 'Document d\'installation.',
    'spamdeleted' => 'Commentaire indsirable supprim',
    'foundspam' => 'Correspondance de commentaire indsirable trouve ',
    'foundspam2' => ' envoy par l\'utilisateur ',
    'foundspam3' => ' adresse IP ',
    'deletespam' => 'Supprimer Commentaire',
    'numtocheck' => 'Nombre de commentaires  vrifier',
    'note1' => '<p>Note: La suppression en lot a pour but de faciliter la tche lorsque vous tes victime d\'un',
    'note2' => ' commentaire indsirable et que Spam-X ne le reconnat pas.  <ul><li>Trouvez d\'abord le(s) lien(s) ou autre ',
    'note3' => 'identificateurs de ce commentaire indsirable et ajoutez-le  votre liste noire personnelle.</li><li>Ensuite ',
    'note4' => 'revenez ici et excutez Spam-X pour vrifier les derniers commentaires.</li></ul><p>Les commentaires ',
    'note5' => 'sont vrifis  partir des plus rcents -- vrifier plus de commentaires ',
    'note6' => 'ncessite plus de temps pour la vrification</p>',
    'masshead' => '<hr' . XHTML . '><h1 align="center">Suppression de commentaires en lot</h1>',
    'masstb' => '<hr' . XHTML . '><h1 align="center">Mass Delete Trackback Spam</h1>',
    'comdel' => ' commentaires supprims.',
    'initial_Pimport' => '<p>Importer Liste Noire Personnelle"',
    'initial_import' => 'Importer Liste Noire Principale Originale',
    'import_success' => '<p>Importation avec succs de %d entres dans la liste noire.',
    'import_failure' => '<p><strong>Erreur:</strong> Aucune entre trouve.',
    'allow_url_fopen' => '<p>Dsol, la configuration de votre serveur web ne permet pas la lecture de fichiers distants (<code>allow_url_fopen</code> est dsactiv). Veuillez tlcharger la liste noire de l\'adresse suivante et placez-la dans le rpertoire "data" de Geeklog, <tt>%s</tt>, avant un nouvel essai:',
    'documentation' => 'Documentation du Plugin Spam-X',
    'emailmsg' => "Un nouveau commentaire indsirable a t envoy  \"%s\"\nUser UID:\"%s\"\n\nContent:\"%s\"",
    'emailsubject' => 'Spam post at %s',
    'ipblack' => 'Spam-X IP Blacklist',
    'ipofurlblack' => 'Spam-X IP of URL Blacklist',
    'headerblack' => 'Spam-X HTTP Header Blacklist',
    'headers' => 'Request headers:',
    'stats_headline' => 'Spam-X Statistics',
    'stats_page_title' => 'Blacklist',
    'stats_entries' => 'Entries',
    'stats_mtblacklist' => 'MT-Blacklist',
    'stats_pblacklist' => 'Personal Blacklist',
    'stats_ip' => 'Blocked IPs',
    'stats_ipofurl' => 'Blocked by IP of URL',
    'stats_header' => 'HTTP headers',
    'stats_deleted' => 'Posts deleted as spam',
    'invalid_email_or_ip' => 'Invalid e-mail address or IP address has been blocked.',
    'email_ip_spam' => '%s or %s attempted to register but was considered a spammer.',
    'edit_personal_blacklist' => 'Edit Personal Blacklist',
    'mass_delete_spam_comments' => 'Mass Delete Spam Comments',
    'mass_delete_trackback_spam' => 'Mass Delete Trackback Spam',
    'edit_http_header_blacklist' => 'Edit HTTP Header Blacklist',
    'edit_ip_blacklist' => 'Edit IP Blacklist',
    'edit_ip_url_blacklist' => 'Edit IP of URL Blacklist',
    'edit_sfs_blacklist' => 'Edit SFS Email Blacklist',
    'edit_slv_whitelist' => 'Edit SLV Whitelist',
    'plugin_name' => 'Spam-X',
    'slvwhitelist' => 'SLV Whitelist'
);

// Define Messages that are shown when Spam-X module action is taken
$PLG_spamx_MESSAGE128 = 'Commentaire indsirable dtect et Commentaire ou Message supprim.';
$PLG_spamx_MESSAGE8 = 'Commentaire indsirable dtect et Commentaire supprim. Courriel envoy  l\Administrateur.';

// Messages for the plugin upgrade
$PLG_spamx_MESSAGE3001 = 'Plugin upgrade not supported.';
$PLG_spamx_MESSAGE3002 = $LANG32[9];

// Localization of the Admin Configuration UI
$LANG_configsections['spamx'] = array(
    'label' => 'Spam-X',
    'title' => 'Spam-X Configuration'
);

$LANG_confignames['spamx'] = array(
    'spamx_action' => 'Spam-X Actions',
    'notification_email' => 'Notification Email',
    'logging' => 'Enable Logging',
    'timeout' => 'Timeout',
    'sfs_enabled' => 'Enable SFS',
    'snl_enabled' => 'Enable SNL',
    'snl_num_links' => 'Number of links'
);

$LANG_configsubgroups['spamx'] = array(
    'sg_main' => 'Main Settings'
);

$LANG_tab['spamx'] = array(
    'tab_main' => 'Spam-X Main Settings',
    'tab_modules' => 'Modules'
);

$LANG_fs['spamx'] = array(
    'fs_main' => 'Spam-X Main Settings',
    'fs_sfs' => 'Stop Forum Spam (SFS)',
    'fs_snl' => 'Spam Number of Links (SNL)'
);

// Note: entries 0, 1, 9, and 12 are the same as in $LANG_configselects['Core']
$LANG_configselects['spamx'] = array(
    0 => array('True' => 1, 'False' => 0),
    1 => array('True' => true, 'False' => false)
);

?>
